==> ecompus-cas-1.0.1-sources.jar: edu/ecompus/cas/dao/impl/UserDaoImpl.java <==
package edu.ecompus.cas.dao.impl;


import java.util.List;

import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Repository;

import edu.ecompus.cas.dao.UserDAO;
import edu.ecompus.cas.entity.User;
import edu.ecompus.core.dao.impl.ML2TemplateGenericDao;
import edu.ecompus.core.entity.Page;


/**
 * 用户数据持久类 操作接口实现
 * 
 * 
 * CopyRright (c) 2013:   <紫悦新橙>
 * Project:               <数字化校园 >
 * Module ID:   <(模块)类编号，可以引用系统设计中的类编号>
 * Comments:  <对此类的描述，可以引用系统设计中的描述>
 * JDK version used:      <JDK1.6> 
 * @author Author：        <JannyShao>
 * Create Date：  <2013-6-24 下午1:54:24>
 */ 
@Repository
public class UserDaoImpl extends ML2TemplateGenericDao<User> implements UserDAO {

	public UserDaoImpl() {
		super(User.class);
	}

	@Override
	public User getUser(String username) {
		StringBuffer sql = new StringBuffer("from User where id>0 ");
		sql.append(" and username='").append(username).append("'");
		
		return (User) this.queryForObject(sql.toString(), null);
	}

	@SuppressWarnings("unchecked")
	@Override
	public User getUserByNickName(String nickname) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and nickname='").append(nickname).append("'");
		
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		
		return null;
	}
	
	@Override
	public User getUser(String username, String password) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and username='").append(username).append("'");
		sql.append(" and password='").append(password).append("'");
		
		return (User) this.queryForObject(sql.toString(), null);
	}


	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserListBySchool(Long schoolId) {
		String sql = "from User where school_id = ?";
		return this.hibernateTemplate.find(sql, new Object[]{schoolId});
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserByIds(String ids) {
		return this.hibernateTemplate.find("from User where id in ("+ids+")");
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryAll() {
		return this.findAll();
	}

	@Override
	public int setUserFace(User user) {
		StringBuffer sql = new StringBuffer("UPDATE User SET userface=?  where id=?");
		return this.executeUpdate(sql.toString(), new Object[]{user.getUserface(),user.getId()});
	}

	@Cacheable(value="default",key="'usercachebykey_' + #userId")
	@Override
	public User queryUserById(Long userId) {
		return this.query(userId);
	}

	@Override
	public boolean queryIsUserById(Long userId) {
		StringBuffer sql = new StringBuffer("from User where id=");
		sql.append(userId);
		User user = (User) this.queryForObject(sql.toString(), null);
		if (user != null) {
			return true;
		}else{
			return false;
		}
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserListBySchool(int type, Long schoolId) {
		StringBuffer sql = new StringBuffer("from User where enable=1");
		
		if(schoolId!=null && schoolId>0){
			sql.append(" and school_id=").append(schoolId);
		}
		
		if(type!=-1){
			sql.append(" and type=").append(type);
		}
		
		//sql.append(" order by name asc");
		
		return this.hibernateTemplate.find(sql.toString(), new Object[]{});
		
	}

	@Override
	public int updatePassWord(User user) {
		String sql = "UPDATE User SET password=?  where id=?";
		return this.executeUpdate(sql.toString(), new Object[]{user.getPassword(),user.getId()});
	}

	@Override
	public int updateUser(User user) {
		String sql = "UPDATE User SET nickname=?, mobile=?, QQ=?, email=?, address=?, introduction=?, province=?, city=?, area=?, birth=? where id=?";
		return this.executeUpdate(sql.toString(), new Object[]{user.getNickname(), user.getMobile(), user.getQQ(), user.getEmail(), user.getAddress(), user.getIntroduction(), user.getProvince(), user.getCity(), user.getArea(), user.getBirth(), user.getId()});
	}

	@SuppressWarnings("unchecked")
	@Override
	public User getUserByMobile(String mob) {
		StringBuffer sql = new StringBuffer("from User where enable=1 and mobile='").append(mob).append("'");
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		// TODO Auto-generated method stub
		return null;
	}

	
	@SuppressWarnings("unchecked")
	@Override
	public User getUserByName(String name) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and name='").append(name).append("'");
		
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		
		return null;
	}
	

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserList(String keyword, Long schoolId,
			int enabled, String mobile, String identity, Page page) {
		
		StringBuffer sql = new StringBuffer("from User where id>0 ");
		if(keyword!=null && !"".equals(keyword)){
			sql.append(" and ( name like '%").append(keyword).append("%'");
			sql.append(" or nickname like '%").append(keyword).append("%' )");
		}
		
		if(schoolId!=null && schoolId>0){
			sql.append(" and school_id=").append(schoolId);
		}
		
		if(enabled!=-1){
			sql.append(" and enable=").append(enabled);
		}
		
		if(mobile!=null && !"".equals(mobile)){
			sql.append(" and mobile like '%").append(mobile).append("%'");
		}
		
		if(identity!=null && !"".equals(identity)){
			sql.append(" and identity like '%").append(identity).append("%'");
		}
		
		
		if(page==null){
			return this.hibernateTemplate.find(sql.toString());
		}
		
		return this.queryForList("select count(*) " + sql.toString(),
				sql.toString(), new Object[] {}, page);
		
	}

	@Override
	public void creatUser(User user) {
		this.creatUser(user);
	}

}

==> ecompus-cas-1.0.2-sources.jar: edu/ecompus/cas/dao/impl/UserDaoImpl.java <==
package edu.ecompus.cas.dao.impl;


import java.util.List;

import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Repository;

import edu.ecompus.cas.dao.UserDAO;
import edu.ecompus.cas.entity.User;
import edu.ecompus.core.dao.impl.ML2TemplateGenericDao;
import edu.ecompus.core.entity.Page;


/**
 * 用户数据持久类 操作接口实现
 * 
 * 
 * CopyRright (c) 2013:   <紫悦新橙>
 * Project:               <数字化校园 >
 * Module ID:   <(模块)类编号，可以引用系统设计中的类编号>
 * Comments:  <对此类的描述，可以引用系统设计中的描述>
 * JDK version used:      <JDK1.6> 
 * @author Author：        <JannyShao>
 * Create Date：  <2013-6-24 下午1:54:24>
 */ 
@Repository
public class UserDaoImpl extends ML2TemplateGenericDao<User> implements UserDAO {

	public UserDaoImpl() {
		super(User.class);
	}

	@Override
	public User getUser(String username) {
		StringBuffer sql = new StringBuffer("from User where id>0 ");
		sql.append(" and username='").append(username).append("'");
		
		return (User) this.queryForObject(sql.toString(), null);
	}

	@SuppressWarnings("unchecked")
	@Override
	public User getUserByNickName(String nickname) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and nickname='").append(nickname).append("'");
		
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		
		return null;
	}
	
	@Override
	public User getUser(String username, String password) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and username='").append(username).append("'");
		sql.append(" and password='").append(password).append("'");
		
		return (User) this.queryForObject(sql.toString(), null);
	}


	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserListBySchool(Long schoolId) {
		String sql = "from User where school_id = ?";
		return this.hibernateTemplate.find(sql, new Object[]{schoolId});
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserByIds(String ids) {
		return this.hibernateTemplate.find("from User where id in ("+ids+")");
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryAll() {
		return this.findAll();
	}

	@Override
	public int setUserFace(User user) {
		StringBuffer sql = new StringBuffer("UPDATE User SET userface=?  where id=?");
		return this.executeUpdate(sql.toString(), new Object[]{user.getUserface(),user.getId()});
	}

	@Cacheable(value="default",key="'usercachebykey_' + #userId")
	@Override
	public User queryUserById(Long userId) {
		return this.query(userId);
	}

	@Override
	public boolean queryIsUserById(Long userId) {
		StringBuffer sql = new StringBuffer("from User where id=");
		sql.append(userId);
		User user = (User) this.queryForObject(sql.toString(), null);
		if (user != null) {
			return true;
		}else{
			return false;
		}
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserListBySchool(int type, Long schoolId) {
		StringBuffer sql = new StringBuffer("from User where enable=1");
		
		if(schoolId!=null && schoolId>0){
			sql.append(" and school_id=").append(schoolId);
		}
		
		if(type!=-1){
			sql.append(" and type=").append(type);
		}
		
		//sql.append(" order by name asc");
		
		return this.hibernateTemplate.find(sql.toString(), new Object[]{});
		
	}

	@Override
	public int updatePassWord(User user) {
		String sql = "UPDATE User SET password=?  where id=?";
		return this.executeUpdate(sql.toString(), new Object[]{user.getPassword(),user.getId()});
	}

	@Override
	public int updateUser(User user) {
		String sql = "UPDATE User SET nickname=?, mobile=?, QQ=?, email=?, address=?, introduction=?, province=?, city=?, area=?, birth=? where id=?";
		return this.executeUpdate(sql.toString(), new Object[]{user.getNickname(), user.getMobile(), user.getQQ(), user.getEmail(), user.getAddress(), user.getIntroduction(), user.getProvince(), user.getCity(), user.getArea(), user.getBirth(), user.getId()});
	}

	@SuppressWarnings("unchecked")
	@Override
	public User getUserByMobile(String mob) {
		StringBuffer sql = new StringBuffer("from User where enable=1 and mobile='").append(mob).append("'");
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		// TODO Auto-generated method stub
		return null;
	}

	
	@SuppressWarnings("unchecked")
	@Override
	public User getUserByName(String name) {
		StringBuffer sql = new StringBuffer("from User where id>0");
		sql.append(" and name='").append(name).append("'");
		
		List<User> list = this.hibernateTemplate.find(sql.toString());
		if(list!=null && list.size()>0){
			return list.get(0);
		}
		
		return null;
	}
	

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserList(String keyword, Long schoolId,
			int enabled, String mobile, String identity, Page page) {
		
		StringBuffer sql = new StringBuffer("from User where id>0 ");
		if(keyword!=null && !"".equals(keyword)){
			sql.append(" and ( name like '%").append(keyword).append("%'");
			sql.append(" or nickname like '%").append(keyword).append("%' )");
		}
		
		if(schoolId!=null && schoolId>0){
			sql.append(" and school_id=").append(schoolId);
		}
		
		if(enabled!=-1){
			sql.append(" and enable=").append(enabled);
		}
		
		if(mobile!=null && !"".equals(mobile)){
			sql.append(" and mobile like '%").append(mobile).append("%'");
		}
		
		if(identity!=null && !"".equals(identity)){
			sql.append(" and identity like '%").append(identity).append("%'");
		}
		
		
		if(page==null){
			return this.hibernateTemplate.find(sql.toString());
		}
		
		return this.queryForList("select count(id) " + sql.toString(),
				sql.toString(), new Object[] {}, page);
		
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<User> queryUserListInCommonUser(String keyword, int enabled,
			Page page) {
		StringBuffer sql = new StringBuffer("from User where id>0 and (type=1 or type=2) ");
		if(keyword!=null && !"".equals(keyword)){
			sql.append(" and ( name like '%").append(keyword).append("%'");
			sql.append(" or nickname like '%").append(keyword).append("%' )");
		}
		
		if(enabled!=-1){
			sql.append(" and enable=").append(enabled);
		}
		
		
		if(page==null){
			return this.hibernateTemplate.find(sql.toString());
		}
		
		return this.queryForList("select count(id) " + sql.toString(),
				sql.toString(), new Object[] {}, page);
	}

}
